@@ -33,9 +33,9 @@ HEADER_KEASE_API_KEY = "x-kease-api-key"
 HEADER_CONTENT_TYPE = "Content-Type"
 HEADER_USER_AGENT = "User-Agent"
 
-HEADER_VALUE_API_KEY = "79fd0eb6-381d-4adf-95a0-47721289d1d9"
+HEADER_VALUE_API_KEY = "7cab4bbd-2693-4fc1-b99b-dec0fb20f9d4"
 HEADER_VALUE_CONTENT_TYPE = "application/json"
-HEADER_VALUE_USER_AGENT = "August/2019.12.16.4708 CFNetwork/1121.2.2 Darwin/19.3.0"
+HEADER_VALUE_USER_AGENT = "August/Luna-11.3.0 (Android; SDK 32; gphone64_arm64)"
 HEADER_VALUE_ACCEPT_VERSION = "0.0.1"
 
 API_BASE_URL = "https://api-production.august.com"
@@ -60,6 +60,14 @@ API_GET_LOCK_STATUS_URL = API_BASE_URL + "/locks/{lock_id}/status"
 API_GET_PINS_URL = API_BASE_URL + "/locks/{lock_id}/pins"
 API_LOCK_URL = API_BASE_URL + "/remoteoperate/{lock_id}/lock"
 API_UNLOCK_URL = API_BASE_URL + "/remoteoperate/{lock_id}/unlock"
+API_LOCK_ASYNC_URL = API_BASE_URL + "/remoteoperate/{lock_id}/lock?v=2.2.15&type=async"
+API_UNLOCK_ASYNC_URL = (
+    API_BASE_URL + "/remoteoperate/{lock_id}/unlock?v=2.2.15&type=async"
+)
+API_STATUS_ASYNC_URL = (
+    API_BASE_URL + "/remoteoperate/{lock_id}/status?v=2.2.15&type=async&intent=wakeup"
+)
+HYPER_BRIDGE_PARAM = "&connection=persistent"
 API_GET_USER_URL = API_BASE_URL + "/users/me"
 
 
