@@ -1,5 +1,6 @@
 import datetime
 from enum import Enum
+from typing import List, Optional
 
 import dateutil.parser
 
@@ -194,6 +195,33 @@ class LockDetail(DeviceDetail):
         """Lookup user data by id."""
         return self._data.get("users", {}).get(user_id)
 
+    @property
+    def offline_keys(self) -> dict:
+        return self._data.get("OfflineKeys", {})
+
+    @property
+    def loaded_offline_keys(self) -> List[dict]:
+        return self.offline_keys.get("loaded", [])
+
+    @property
+    def offline_key(self) -> Optional[str]:
+        loaded_offline_keys = self.loaded_offline_keys
+        if loaded_offline_keys and "key" in loaded_offline_keys[0]:
+            return loaded_offline_keys[0]["key"]
+        return None
+
+    @property
+    def offline_slot(self) -> Optional[int]:
+        loaded_offline_keys = self.loaded_offline_keys
+        if loaded_offline_keys and "slot" in loaded_offline_keys[0]:
+            return loaded_offline_keys[0]["slot"]
+        return None
+
+    @property
+    def mac_address(self) -> Optional[str]:
+        mac = self._data.get("macAddress")
+        return mac.upper() if mac else None
+
 
 class LockStatus(Enum):
     LOCKED = "locked"
